/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2011. All Rights Reserved.
 *
 * TotalCostScriptedCalculatedValue
 *
 * Note to U.S. Government Users Restricted Rights:  
 * Use, duplication or disclosure restricted by GSA ADP Schedule 
 * Contract with IBM Corp. 
 *******************************************************************************/
dojo.provide("com.acme.providers.script.TotalCostScriptedCalculatedValue");
dojo.require("com.ibm.team.workitem.api.common.WorkItemAttributes");


/**
 * @see https://jazz.net/wiki/bin/view/Main/AttributeCustomization#Using_scripts_for_attribute_cust
 * @see https://jazz.net/wiki/bin/view/Main/AttributeCustomization#API_Example
 */
(function() {
	var doDebug = true;
	var scriptname = "TotalCostScriptedCalculatedValue";

    dojo.declare("com.acme.providers.script.TotalCostScriptedCalculatedValue", null, {

        getValue: function(attribute, workItem, configuration) {
        	debug(" - Start"); 
     
        	var estimatedInvest = workItem.getValue("com.acme.openup.workitem.attribute.estinvest");
        	debug("Estimated Invest: " + estimatedInvest);
        	var estimatedEffort = workItem.getValue("com.acme.openup.workitem.attribute.esteffort");
        	debug("Estimated Effort: " + estimatedEffort);
			var averageCost	= workItem.getValue("com.acme.openup.workitem.attribute.cost");
			debug("AverageCost: " + averageCost);
			
           	estimatedInvest=convertValue(estimatedInvest);
        	debug("Estimated Invest converted: " + estimatedInvest);
           	estimatedEffort=convertValue(estimatedEffort);
        	debug("Estimated Effort converted: " + estimatedEffort);
           	averageCost=convertValue(averageCost);
			debug("AverageCost converted: " + averageCost);
			
           	var totalCost = new String(parseInt(estimatedEffort)*parseInt(averageCost)+parseInt(estimatedInvest));
           	if(parseInt(totalCost)>0){
           		debug(" - Total cost: " + totalCost);
           		return totalCost;
           	}
           	debug(" - return no cost");	
           	return "";	        	
           	
           	// Used functions
           	
	    	/**
	    	 * Debug output. Set doDebug to true or false to switch debugging on and off 
	    	 * @param display
	    	 */
	    	function debug(display){	    		
	    		if(doDebug){
	        		console.log(scriptname + " " + display);
	    		}
	    	}
	    	
	    	 
			

        	/**
        	 * Converts value of type number<modifier> with modifiers  
        	 * m, w, d, h for month, weeks, days M, T for millions and thousands
        	 * 
        	 * @param value
        	 * @returns
        	 */
        	function convertValue (value){
        		debug("convertValue");
        		var calc = handleUndefined(value);
        		var slen=calc.length;
        		var modifier = calc.substring(slen-1, slen);
        		var factor = getFactor(modifier);
        		if(factor!=""){
        			var numbervalue=calc.substring(0,slen-1);
        			calc = numbervalue*factor;
        		}
        		return calc;
        	}
        	
        	/**
        	 * Handles null or empty strings
        	 *  
        	 * @param value
        	 * @returns Value or "0" if value was null or empty.
        	 */
        	function handleUndefined (value){
        		if(value==null){
        			value="0"; 
        		}
        		if(value==""){
        			value="0"; 
        		}
        		return value;
        	}
        	
        	/**
        	 * Accepts a modifier and calculates the factor for the modifier.
        	 * 
        	 * @param modifier
        	 * @returns {String} The factor or "" if the modifier was not valid.
        	 */
        	function getFactor(modifier){
        		// m, w, d, h for month, weeks, days...
        		// M, T for millions and thousands
        		debug("getFactor");
        		var factor = "";
        		switch (modifier) {
				case 'w':
					factor = "40";
					break;
				case 'm':
					factor = "240";
					break;
				case 'd':
					factor = "8";
					break;
				case 'h':
					factor = "1";
					break;
				case 'T':
					factor = "1000";
					break;
				case 'M':
					factor = "1000000";
					break;
				default:
					factor = "";
					break;
				}
        		debug("getFactor:" + factor);
       		    return factor;
        	}
        }
    });
})();